
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.0rc1',
    'branch_nick': 'feature-0-Release__Rucio_1_20_0rc1_preparation',
    'revision_id': '194eed686dee2ce76ad4a60283f62a4e33f9a38f',
    'revno': 8288
}
